@@ -1,6 +1,6 @@
 #' @importFrom utils globalVariables
 
-globalVariables(c(".","k","Segment.Level","Segment.Child","Quant.Error",
+utils::globalVariables(c(".","k","Segment.Level","Segment.Child","Quant.Error",
                          "noOfCellsBelowQuantizationError","noOfCells","index",
                          "Segment.Parent","cluster","child","value", "hvq_k","..count..",":=",
                          "min_dist", "perc", "Centroid_Type", "polygon_x", "polygon_y",
